aboutsummarylogtreecommitdiffstats
path: root/portfolio.h
diff options
context:
space:
mode:
authorAntony Kellermann2018-05-13 14:30:17 -0400
committerAntony Kellermann2018-05-13 14:30:17 -0400
commit6d8ce134613367a36c36a40e55043b817703fc6d (patch)
tree4cea9cb115891d17925fc4d44918da5104e9e041 /portfolio.h
parent6c833af5fce3be8ed1d572df68d018449fde3786 (diff)
downloadaur-6d8ce134613367a36c36a40e55043b817703fc6d.tar.gz
Implemented multithreading for check for O(1) compute time
Diffstat (limited to 'portfolio.h')
-rw-r--r--portfolio.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/portfolio.h b/portfolio.h
index b0bc83a5d642..2836e4f11592 100644
--- a/portfolio.h
+++ b/portfolio.h
@@ -3,6 +3,7 @@
#include <math.h>
#include <sys/stat.h>
+#include <pthread.h>
#include "api.h"
#include "rc4.h"
@@ -93,9 +94,10 @@ SDA* portfolio_get_data_array(void);
/**
* Initializes the rest of the fields in an SD struct using API data after symbol, amount, and total_spent have already
* been stored
* @param sec_data pointer to SD struct
*/
-void portfolio_store_api_data(SD* sec_data);
+void* portfolio_store_api_data(void* vsec_data);
/**
* Sorts the SDA array based on the SORT mode.
@@ -93,9 +94,10 @@ SDA* portfolio_get_data_array(void);
* Initializes the rest of the fields in an SD struct using API data after symbol, amount, and total_spent have already
* been stored
- * @param sec_data pointer to SD struct
+ * @param vsec_data pointer to an SD struct. Must be void* for threading.
+ * @return returns NULL. Must return NULL for threading.
*/